==> library1.4.1.tar.bz2: library/alfaut-search.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "utils/chlang_osn.php";

$title = $TEXT['search-alf-aut'];

require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top.php";

if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

if(strlen($_GET['k'])>8) {puterror($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom_adm.php"; exit();}
if(strlen($_GET['bukva'])>4) {puterror($result2['skin'],$TEXT['error-bukva']); require_once "utils/bottom_adm.php"; exit();}
if(strlen($_POST['bukva'])>4) {puterror($result2['skin'],$TEXT['error-bukva']); require_once "utils/bottom_adm.php"; exit();}
$_GET['bukva'] = rep($_GET['bukva']);
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;

if(empty($_GET['bukva']))
 {
  if(empty($_POST['bukva'])) {$bukva = "А";}
   else {$bukva = $_POST['bukva'];}
} else {$bukva = $_GET['bukva'];}
?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="95%" >
<tr>
<td align="center">
<?php
    $query_body1 = "SELECT DISTINCT first_bt AS bukva FROM `tbl_autor` ORDER BY bukva ";
     $result_body1 = mysqli_query($dbcnx,$query_body1);
     if(!$result_body1) {puterror($result2['skin'],$TEXT['error-tbl1']); require_once "utils/bottom.php"; exit();}
      while($result_body_autor1 = mysqli_fetch_array($result_body1))
       {
       if($bukva == $result_body_autor1['bukva']) {echo "&nbsp;<a class='zagolovok' href='alfaut-search.php?bukva=".$result_body_autor1['bukva']."' title='".$TEXT['alf-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
        else {echo "&nbsp;<a href='alfaut-search.php?bukva=".$result_body_autor1['bukva']."' title='".$TEXT['alf-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
       }
?>
</td>
</tr>
</table>
<hr width="70%" />
<table align="center" border="0" cellpadding="3" cellspacing="0" width="90%" >
<tbody id="tab" >
<?php
     $query_body = "SELECT familiya, name, otchestvo, autor_id, first_bt
     FROM `tbl_autor`
     WHERE first_bt = '".$bukva."'
     ORDER BY familiya 
     LIMIT $lim_ogr";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror($result2['skin'],$TEXT['error-tbl1']); require_once "utils/bottom.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows > 0)
         {
           while($result_body_autor = mysqli_fetch_array($result_body))
               {
              $query_book_cicle = mysqli_query($dbcnx,"SELECT COUNT(autor_id) AS co_autor_id FROM tbl_s_book_aut WHERE autor_id='".$result_body_autor['autor_id']."'");
	      $coun_book_cicle = mysqli_fetch_array($query_book_cicle);
              $book = "<a href=extsearch.php?autor_id=".$result_body_autor['autor_id']."&amp;autor_ch=on title='".$TEXT['search-all-aut']."'>  (".$TEXT['global-now']." ".$coun_book_cicle['co_autor_id'].")</a>";
              $usr_name = "<a href=info_autor.php?autor_id=".$result_body_autor['autor_id']."&amp;bukva=".$result_body_autor['first_bt']." title='".$TEXT['aut-viewtit']."'><span class='zagolovok'>".$result_body_autor['name']." ".$result_body_autor['otchestvo']." ".$result_body_autor['familiya']."</span></a>";
           ?>
           <tr>
              <td align= "right" width="50%"><?php echo $usr_name; ?></td>
              <td align= "left" width="50%"><?php echo $book; ?></td>
           </tr>
           <?php
               }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(autor_id) AS c_autor_id FROM tbl_autor WHERE `first_bt` = '".$bukva."'");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_autor_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva']."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva']."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva'].">".$j."</option>";}
                       else {echo "<option value=alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva'].">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
require_once "utils/bottom.php";
?>

==> library1.19.1.tar.bz2: library/alfaut-search.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "utils/chlang_osn.php";

$title = $TEXT['search-alf-aut'];

require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top.php";

if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

if(strlen($_GET['k'])>8) {puterror($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom_adm.php"; exit();}
if(strlen($_GET['bukva'])>4) {puterror($result2['skin'],$TEXT['error-bukva']); require_once "utils/bottom_adm.php"; exit();}
if(strlen($_POST['bukva'])>4) {puterror($result2['skin'],$TEXT['error-bukva']); require_once "utils/bottom_adm.php"; exit();}
$_GET['bukva'] = rep($_GET['bukva']);
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;

if(empty($_GET['bukva']))
 {
  if(empty($_POST['bukva'])) {$bukva = "А";}
   else {$bukva = $_POST['bukva'];}
} else {$bukva = $_GET['bukva'];}
?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="95%" >
<tr>
<td align="center">
<?php
    $query_body1 = "SELECT DISTINCT first_bt AS bukva FROM `tbl_autor` ORDER BY bukva ";
     $result_body1 = mysqli_query($dbcnx,$query_body1);
     if(!$result_body1) {puterror($result2['skin'],$TEXT['error-tbl1']); require_once "utils/bottom.php"; exit();}
      while($result_body_autor1 = mysqli_fetch_array($result_body1))
       {
       if($bukva == $result_body_autor1['bukva']) {echo "&nbsp;<a class='zagolovok' href='alfaut-search.php?bukva=".$result_body_autor1['bukva']."' title='".$TEXT['alf-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
        else {echo "&nbsp;<a href='alfaut-search.php?bukva=".$result_body_autor1['bukva']."' title='".$TEXT['alf-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
       }
?>
</td>
</tr>
</table>
<hr width="70%" />
<table align="center" border="0" cellpadding="3" cellspacing="0" width="90%" >
<tbody id="tab" >
<?php
     $query_body = "SELECT familiya, name, otchestvo, autor_id, first_bt
     FROM `tbl_autor`
     WHERE first_bt = '".$bukva."'
     ORDER BY familiya 
     LIMIT $lim_ogr";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror($result2['skin'],$TEXT['error-tbl1']); require_once "utils/bottom.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows > 0)
         {
           while($result_body_autor = mysqli_fetch_array($result_body))
               {
              $query_book_cicle = mysqli_query($dbcnx,"SELECT COUNT(autor_id) AS co_autor_id FROM tbl_s_book_aut WHERE autor_id='".$result_body_autor['autor_id']."'");
	      $coun_book_cicle = mysqli_fetch_array($query_book_cicle);
              $book = "<a href='extsearch.php?autor_id=".$result_body_autor['autor_id']."&amp;autor_ch=on' title='".$TEXT['search-all-aut']."'>  (".$TEXT['global-now']." ".$coun_book_cicle['co_autor_id'].")</a>";
              $usr_name = "<a href='info_autor.php?autor_id=".$result_body_autor['autor_id']."&amp;bukva=".$result_body_autor['first_bt']."' title='".$TEXT['aut-viewtit']."'><span class='zagolovok'>".rep_back($result_body_autor['name'])." ".rep_back($result_body_autor['otchestvo'])." ".rep_back($result_body_autor['familiya'])."</span></a>";
           ?>
           <tr>
              <td align= "right" width="50%"><?php echo $usr_name; ?></td>
              <td align= "left" width="50%"><?php echo $book; ?></td>
           </tr>
           <?php
               }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(autor_id) AS c_autor_id FROM tbl_autor WHERE `first_bt` = '".$bukva."'");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_autor_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva']."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva']."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva'].">".$j."</option>";}
                       else {echo "<option value=alfaut-search.php?k=".$k."&amp;bukva=".$_GET['bukva'].">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
require_once "utils/bottom.php";
?>
